#ifndef GRANULEPOSINTERPRETER_H_
#define GRANULEPOSINTERPRETER_H_

#include "oggPacket.h"
#include "streamParameter.h"

class GranulePosInterpreter {

  protected:
    bool initialized;

    int64 actualGranulePosition;

  public:
    GranulePosInterpreter();
    virtual ~GranulePosInterpreter();

    //! method to initialize the interpreter
    /*! The initialization is needed to be able to
     *  interpret the granule position. E.g. theora splits the
     *  64 Bit into a lower and upper part for the last keyframe
     *  position and a counter for the p-frames. This split
     *  is depending on the header information in the first page.
     */
    virtual void initialize(StreamParameter* parameter) = 0;
/*
     virtual void initialize(OggPage firstPage) = 0;

    virtual void initialize(OggPacket firstPacket) = 0;
*/
    //! method to interpret the time from a granule position
    /*! This method interprets the given granule position by the
     *  information from the first page, with which the interpreter has
     *  been initialized. The time does not depend on the actual
     *  internal position counter. */
    virtual double getTime(int64 granulePos) = 0;

    //! method to interprete the internal position to a time
    /*! This method uses the actual internal position information
     *  to calculate the actual time. For the interpretation the method
     *  uses the information given by the first page. */
    double getActTime();

    //! method returns the actual granule position
    virtual int64 getPosition();

    virtual void setStreamPosition(OggPacket& packet) = 0;

    virtual GranulePosInterpreter& operator+=(GranulePosInterpreter& position) = 0;
    virtual GranulePosInterpreter& operator-=(GranulePosInterpreter& position) = 0;

};

#endif /*GRANULEPOSINTERPRETER_H_*/
